## Investigation Task

**Source:** {source_type}
**Reason:** {trigger_reason}

## Context from User's Session

{recent_context}

## Related Knowledge

{insights_text}

{intuitions_text}

## Instructions

Investigate the lead above. Search the web, read relevant files, and query memory as needed. Report what you find.